@@ -13,13 +13,15 @@
  * // fmg 2/15/94 - Added macro filename & Macro define selection to
  *                  Screen & Keyboard menu. Added window for macro
  *                  definition.
- * // jl 22.06.97 - Added logging function
  * // jl 04.09.97 - Added configuring the character conversion tables
  * // jl 09.09.97 - Save conversion table filename in the config file and
  *                  read the table at startup
  * // jl 22.02.98 - Setting for filename selection window
  * // acme 25.02.98 - i18n
- * // jl 05.04.98 - Handling the P_MUL option 
+ * // jl 05.04.98 - Handling the P_MUL option
+ *    jl 06.07.98 - the P_CONVCAP option
+ *    jl 10.07.98 - moved functions pfix_home and do_log to file common.c
+ *    jl 29.11.98 - the P_SHOWSPD option
  */
 #include "port.h"
 #include "minicom.h"
@@ -27,25 +29,6 @@
 
 void doconv();   /* jl 04.09.97 */
 
-#if _HAVE_MACROS
-/* Prefix a non-absolute file with the home directory. */
-static char *pfix_home(s)
-char *s;
-{
-#if defined(FILENAME_MAX)
-  static char buf[FILENAME_MAX];
-#else
-  static char buf[256];
-#endif
-
-  if (s && *s != '/') {
-	snprintf(buf, sizeof(buf),"%s/%s", homedir, s);
-	return(buf);
-  }
-  return(s);
-}
-#endif
-
 /* Read in parameters. */
 void read_parms()
 {
@@ -57,14 +40,14 @@ void read_parms()
   /* Read global parameters */
   if ((fp = fopen(parfile, "r")) == (FILE *)NULL) {
   	if (real_uid == 0) {
-  		fprintf(stderr,
-  	_("minicom: WARNING: configuration file not found, using defaults\n"));
+  		fputs(
+  _("minicom: WARNING: configuration file not found, using defaults\n"),stderr);
   		sleep(2);
   		return;
   	}
   	fprintf(stderr,
 	_("minicom: there is no global configuration file %s\n"), parfile);
-  	fprintf(stderr, _("Ask your sysadm to create one (with minicom -s).\n"));
+  	fputs(_("Ask your sysadm to create one (with minicom -s).\n"), stderr);
   	exit(1);
   }
   readpars(fp, 1);
@@ -550,6 +533,14 @@ static void doserial()
   }
 }
 
+char * sspd(char *sptyp)
+{
+  if (sptyp[0] == 'd')
+    return (_("DTE speed "));
+  else
+    return (_("line speed"));
+}
+
 static void domodem()
 {
   WIN *w;
@@ -570,12 +561,13 @@ static void domodem()
       * dial_time = _(" M - Dial time ..........."),
       * delay_before_redial = _(" N - Delay before redial ."),
       * number_of_tries = _(" O - Number of tries ....."),
-      * auto_bps_detect = _(" P - Auto bps detect ....."),
-      * dtr_drop_time = _(" Q - DTR drop time (0=no)."),
+      * dtr_drop_time = _(" P - DTR drop time (0=no)."),
+      * auto_bps_detect = _(" Q - Auto bps detect ....."),
       * modem_has_dcd_line = _(" R - Modem has DCD line .."),
+      * shown_speed = _(" S - Status line shows ..."),
       * question = _("Change which setting?");
 
-  w = wopen(2, 2, 77, 21, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  w = wopen(2, 2, 77, 22, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
 
   dirflush = 0;
   wtitle(w, TMID, _("Modem and dialing parameter setup"));
@@ -598,14 +590,15 @@ static void domodem()
   wprintf(w, "%s %.3s\n", dial_time, P_MDIALTIME);
   wprintf(w, "%s %.3s\n", delay_before_redial, P_MRDELAY);
   wprintf(w, "%s %.3s\n", number_of_tries, P_MRETRIES);
+  wprintf(w, "%s %.3s\n", dtr_drop_time, P_MDROPDTR);
   wlocate(w, 34, 15);
   wprintf(w, "%s %s\n", auto_bps_detect, _(P_MAUTOBAUD));
   wlocate(w, 34, 16);
-  wprintf(w, "%s %s\n", dtr_drop_time, P_MDROPDTR);
-  wlocate(w, 34, 17);
   wprintf(w, "%s %s\n", modem_has_dcd_line, _(P_HASDCD));
+  wlocate(w, 34, 17);
+  wprintf(w, "%s %s\n", shown_speed, sspd(P_SHOWSPD));
 
-  wlocate(w, 1, 19);
+  wlocate(w, 1, 20);
   wprintf(w, "%s ", question);
   x = w->curx; y = w->cury;
   wprintf(w, _("      (Return or Esc to exit)"));
@@ -628,6 +621,9 @@ static void domodem()
   		case 'O':
 			if (string_size == 0)
 			  string_size = strlen (number_of_tries);
+	    	case 'P':
+			if (string_size == 0)
+			  string_size = strlen (dtr_drop_time);
 			  
   			ypos++;
 			maxl = 4;
@@ -635,6 +631,9 @@ static void domodem()
 			if (string_size == 0)
 			  string_size = strlen (hangup_string);
   		case 'L':
+			if (string_size == 0)
+			  string_size = strlen (dial_cancel_string);
+
   			ypos -= 2;
   			c += 3;
   		case 'A':
@@ -677,22 +676,23 @@ static void domodem()
   			pgets(w, string_size + 1 , 11, P_MNOCON3, 20, 64);
   			pgets(w, string_size + 1 + 22, 11, P_MNOCON4, 20, 64);
   			break;
-  		case 'P':
+  		case 'Q':
   			psets(P_MAUTOBAUD, yesno(P_MAUTOBAUD[0] == 'N'));
   			wlocate(w, 35 + strlen (auto_bps_detect), 15);
   			wputs(w, _(P_MAUTOBAUD));
   			break;
-	    	case 'Q':
-		  /*	psets(P_MDROPDTR, yesno(P_MDROPDTR[0] == 'N')); */
-  			pgets(w, 35 + strlen (dtr_drop_time), 16, P_MDROPDTR, 3, 3);
-			/* wputs(w, P_MDROPDTR); */
-			break; 
   		case 'R':
   			psets(P_HASDCD, yesno(P_HASDCD[0] == 'N'));
-  			wlocate(w, 35 + strlen (modem_has_dcd_line), 17);
+  			wlocate(w, 35 + strlen (modem_has_dcd_line), 16);
   			wputs(w, _(P_HASDCD));
   			break;
-  		case '\n':
+		case 'S':
+			psets(P_SHOWSPD, P_SHOWSPD[0] == 'd' ? "l": "d");
+			wlocate(w, 35 + strlen (shown_speed), 17);
+			wputs(w, sspd(P_SHOWSPD));
+			mode_status();
+			break;
+		case '\n':
   			dirflush = 1;
   			wclose(w, 1);
   			return;
@@ -1264,7 +1264,8 @@ static char *J_col[] =
     N_("BLUE"), N_("MAGENTA"), N_("CYAN"), N_("WHITE") };
 
 static char *speeds[] =
-   { "300", "1200", "2400", "9600", "19200", "38400", "57600", "115200", "Curr" };
+   { "300", "1200", "2400", "4800" , 
+     "9600", "19200", "38400", "57600", "115200", "Curr" };
 
 /*
  * Ask user for Baudrate, Bits and Parity
@@ -1287,30 +1288,31 @@ int curr_ok;
 
   wlocate(w, 0, 3);
   wputs(w, _("   Speed          Parity          Data\n\n"));
-  wputs(w, _(" A: 300           J: None         Q: 5\n"));
-  wputs(w, _(" B: 1200          K: Even         R: 6\n"));
-  wputs(w, _(" C: 2400          L: Odd          S: 7\n"));
-  wputs(w, _(" D: 9600          M: Mark         T: 8\n"));
+  wputs(w, _(" A: 300           K: None         R: 5\n"));
+  wputs(w, _(" B: 1200          L: Even         S: 6\n"));
+  wputs(w, _(" C: 2400          M: Odd          T: 7\n"));
+  wputs(w, _(" D: 4800          N: Mark         U: 8\n"));
+  wputs(w, _(" E: 9600\n"));
   if (max > 96)
-	wputs(w, _(" E: 19200         N: Space\n"));
+	wputs(w, _(" F: 19200         O: Space\n"));
   else
-	wputs(w, _("                  N: Space\n"));
+	wputs(w, _("                  O: Space\n"));
   if (max > 192)
-	wputs(w, _(" F: 38400\n"));
+	wputs(w, _(" G: 38400\n"));
   else
 	wputs(w, "\n");
   if (max > 384)
-	wputs(w, _(" G: 57600\n"));
+	wputs(w, _(" H: 57600\n"));
   else
 	wputs(w, "\n");
   if (max > 576)
-	wputs(w, _(" H: 115200        O: 8-N-1\n"));
+	wputs(w, _(" I: 115200        P: 8-N-1\n"));
   else
-	wputs(w, _("                  O: 8-N-1\n"));
+	wputs(w, _("                  P: 8-N-1\n"));
   if (curr_ok)
-	wputs(w, _(" I: Current       P: 7-E-1\n"));
+	wputs(w, _(" J: Current       Q: 7-E-1\n"));
   else
-	wputs(w, _("                  P: 7-E-1\n"));
+	wputs(w, _("                  Q: 7-E-1\n"));
   wputs(w, _("\n Choice, or <Enter> to exit? "));
   x = w->curx;
   y = w->cury;
@@ -1328,55 +1330,56 @@ int curr_ok;
   	c = wxgetch();
   	if (c >= 'a') c -= 32;
   	switch(c) {
-  		case 'H':
+  		case 'I':
 			if (max < 1152) break;
-  		case 'G':
+  		case 'H':
 			if (max < 576) break;
-		case 'F':
+		case 'G':
 			if (max < 384) break;
-  		case 'E':
+  		case 'F':
 			if (max < 192) break;
   		case 'A':
   		case 'B':
   		case 'C':
   		case 'D':
-		case 'I':
-			if (c == 'I' && !curr_ok) break;
+  		case 'E':
+		case 'J':
+			if (c == 'J' && !curr_ok) break;
   			strcpy(ba, speeds[c - 'A']);
   			break;
-  		case 'J':
+  		case 'K':
   			pa[0] = 'N';
   			break;
-  		case 'K':
+  		case 'L':
   			pa[0] = 'E';
   			break;
-  		case 'L':
+  		case 'M':
   			pa[0] = 'O';
   			break;
-		case 'M':
+		case 'N':
 			pa[0] = 'M';
 			break;
-		case 'N':
+		case 'O':
 			pa[0] = 'S';
 			break;
-  		case 'O':
+  		case 'P':
   			pa[0] = 'N';
   			bi[0] = '8';
   			break;
-  		case 'P':
+  		case 'Q':
   			pa[0] = 'E';
   			bi[0] = '7';
   			break;
-  		case 'Q':
+  		case 'R':
   			bi[0] = '5';
   			break;
-  		case 'R':
+  		case 'S':
   			bi[0] = '6';
   			break;
-  		case 'S':
+  		case 'T':
   			bi[0] = '7';
   			break;
-  		case 'T':
+  		case 'U':
   			bi[0] = '8';
   			break;
   		case 27:
@@ -1413,7 +1416,7 @@ void domacros()
   int   Jch='1', Jm=0; /* fmg - ok, so I was lazy.. */
   char* question = _("Change which setting?  (Esc to exit)");
 
-  w = wopen(3, 7, 75, 21 , BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  w = wopen(3, 6, 75, 21 , BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
   wtitle(w, TMID, _("F1 to F10 Macros"));
 
   wprintf(w, "\n");
@@ -1433,7 +1436,9 @@ void domacros()
 
   while(1) {
         wlocate(w, 1, 14);
-        wputs(w, _(" (LEGEND: ^M = C-M, ^L = C-L, ^G = C-G, ^R = C-R, ^~ = pause 1 second)"));
+        wputs(w, _(" (LEGEND: ^M = C-M, ^L = C-L, ^G = C-G, ^R = C-R, ^~ = pause 1 second,"));
+	wlocate(w, 1, 15);
+	wputs(w, _("  \\u = username, \\p = password, \\\\ = \\)"));
         if (clr) {
                 wlocate(w, 1, 12);
                 wprintf(w, "%s ", question);
@@ -1525,13 +1530,13 @@ void doconv()
   WIN *w;
   int i, j, k, l,
     offs=32,
-    ymax=21,
+    ymax=22,
     h,
     redraw=1;
   char buf[64];
   char *prompt;
 
-  h = ymax - 5;
+  h = 16;
   w = wopen (1, 1, 77, ymax, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
   wtitle(w, TMID, _("Character conversion"));
   while(1) {
@@ -1540,7 +1545,7 @@ void doconv()
       wprintf(w,
 	      _(" char    in out    char    in out    char    in out    char    in out\n"));
       for (i=offs,j=i+h,k=j+h,l=k+h ;
-	   i<offs+ymax-5 && i<256 ; i++,j++,k++,l++){
+	   i<offs+h && i<256 ; i++,j++,k++,l++){
 	wprintf(w, "%3d (%c) %3d %3d   ",
 		i, prch(i), (int) vt_inmap[i], (int) vt_outmap[i]);
 	if (j<256)
@@ -1562,7 +1567,8 @@ void doconv()
       wprintf(w, _("\n A - load table\tB - save table"));
       if (P_CONVF[0])
 	wprintf(w, _("\tfile:%s"),P_CONVF);
-      wprintf(w, _("\n C - edit char\tD - next screen\tE - prev screen\n "));
+      wprintf(w, _("\n C - edit char\tD - next screen\tE - prev screen\n"));
+      wprintf(w, _(" F - convert capture: %s\n"), _(P_CONVCAP));
       
       wredraw(w, 1);
       redraw=0;
@@ -1602,7 +1608,7 @@ void doconv()
     case 'C':
       prompt=_("Character to be edited: ");
       wprintf(w, prompt);
-      buf[0]=0;
+      buf[0]=0; i=-1;
       wlocate(w, strlen(prompt), ymax - 1);
       wgets(w, buf, 4, 4);
       sscanf(buf,"%d",&i);
@@ -1638,17 +1644,22 @@ void doconv()
       redraw=1;
       break;
     case 'D':
-      offs += 4 * (ymax - 5);
+      offs += 4 * h;
       if (offs > 255)
 	offs = 0;
       redraw=1;
       break;
     case 'E':
-      offs -= 4 * (ymax -5);
+      offs -= 4 * h;
       if (offs < 0)
 	offs = 0;
       redraw=1;
       break;
+    case 'F':
+      strcpy(P_CONVCAP, yesno(P_CONVCAP[0] == 'N'));
+      markch(P_CONVCAP);
+      redraw=1;
+      break;
     }
   }
 }
@@ -1681,35 +1692,3 @@ int saveconv(char *buf)
   return 0;
 }
 #endif
-
-#ifdef LOGFILE
-/* Write a line to the log file.   jl 22.06.97 */
-void do_log(char *line)
-{
-  FILE *logfile;
-#ifdef _HAVE_MACROS
-  char *logname = pfix_home(LOGFILE);
-#else
-  char *logname = LOGFILE;
-#endif
-  struct tm *ptr;
-  time_t    ttime;
-
-  logfile = fopen(logname,"a");
-  if (!logfile) return;
-
-  ttime=time(NULL);
-  ptr=localtime(&ttime);
-
-  fprintf(logfile,"%02d%02d%02d %02d:%02d:%02d %s\n",
-	  ptr->tm_year,(ptr->tm_mon)+1,ptr->tm_mday,
-	  ptr->tm_hour,ptr->tm_min,ptr->tm_sec,
-	  line);
-  fclose(logfile);
-}
-#else
-void do_log(char *line)
-{
-  /* dummy function, don't do anything */
-}
-#endif
