@@ -19,6 +19,8 @@
  *    length of "struct pars" "value" member so it could be referenced
  *    elsewhere.
  * jl  05.04.98 added parameter P_MUL
+ * jl  06.07.98 added parameter P_CONVCAP
+ * jl  28.11.98 added parameter P_SHOWSPD
  */
 
 #define PARS_VAL_LEN 64
@@ -26,7 +28,7 @@
 struct pars {
   /* value is first, so that (char *)mpars[0] == mpars[0].value */
   /* Try doing this in PASCAL !! :-) */
-  char value[64];
+  char value[PARS_VAL_LEN];
   int flags;
   char *desc;
 };
@@ -94,42 +96,44 @@ extern struct macs mmacs[];
 #define P_MRDELAY	mpars[52].value
 #define P_MRETRIES	mpars[53].value
 /* Yup, until here. */
-#define P_MAUTOBAUD	mpars[54].value
-#define P_MDROPDTR	mpars[55].value
-#define P_UPDIR		mpars[56].value
-#define P_DOWNDIR	mpars[57].value
-#define P_SCRIPTDIR	mpars[58].value
-#define P_ESCAPE	mpars[59].value
-#define P_BACKSPACE	mpars[60].value
-#define P_STATLINE	mpars[61].value
-#define P_HASDCD	mpars[62].value
-#define P_HASRTS	mpars[63].value
-#define P_HASXON	mpars[64].value
-#define P_PAUTO		mpars[65].value
+#define P_MDROPDTR	mpars[54].value
+#define P_MAUTOBAUD	mpars[55].value
+#define P_SHOWSPD	mpars[56].value
+#define P_UPDIR		mpars[57].value
+#define P_DOWNDIR	mpars[58].value
+#define P_SCRIPTDIR	mpars[59].value
+#define P_ESCAPE	mpars[60].value
+#define P_BACKSPACE	mpars[61].value
+#define P_STATLINE	mpars[62].value
+#define P_HASDCD	mpars[63].value
+#define P_HASRTS	mpars[64].value
+#define P_HASXON	mpars[65].value
+#define P_PAUTO		mpars[66].value
 
 /* fmg colors - these are used in signaling when values have changed
                 so that the preferences saving function knows what to save */
 
-#define P_MFG           mpars[66].value
-#define P_MBG           mpars[67].value
-#define P_TFG           mpars[68].value
-#define P_TBG           mpars[69].value
-#define P_SFG           mpars[70].value
-#define P_SBG           mpars[71].value
+#define P_MFG           mpars[67].value
+#define P_MBG           mpars[68].value
+#define P_TFG           mpars[69].value
+#define P_TBG           mpars[70].value
+#define P_SFG           mpars[71].value
+#define P_SBG           mpars[72].value
 
 /* fmg  macros file name & entry used to signal when macros need to be saved */
 
-#define P_MACROS        mpars[72].value  /* macros save filename */
-#define P_MACCHG        mpars[73].value  /* macros changed flag */
-#define P_MACENAB	mpars[74].value	 /* macros enabled flag */
+#define P_MACROS        mpars[73].value  /* macros save filename */
+#define P_MACCHG        mpars[74].value  /* macros changed flag */
+#define P_MACENAB	mpars[75].value	 /* macros enabled flag */
 
-#define P_SOUND		mpars[75].value
-#define P_HISTSIZE      mpars[76].value  /* History buffer size */
+#define P_SOUND		mpars[76].value
+#define P_HISTSIZE      mpars[77].value  /* History buffer size */
 
-#define P_CONVF         mpars[77].value  /* Char.conversion table */
+#define P_CONVF		mpars[78].value  /* Char.conversion table */
+#define P_CONVCAP	mpars[79].value  /* Use conversion on capture file */
 
-#define P_FSELW		mpars[78].value  /* Filename selection window */
-#define P_ASKDNDIR	mpars[79].value  /* Ask dir. for downloads or not */
+#define P_FSELW		mpars[80].value  /* Filename selection window */
+#define P_ASKDNDIR	mpars[81].value  /* Ask dir. for downloads or not */
  
 /* fmg - macros struct */
 
