@@ -77,7 +77,7 @@ char *s;
 {
   WIN *w;
 
-  w = tell(s);
+  w = mc_tell(s);
   sleep(1);
   wclose(w, 1);
 }
@@ -262,7 +262,7 @@ GETSDIR_ENTRY *o_dirdat;
 int flushit;
 {
     static int dp_len = 0;
-    static char cwd_str_fmt[BUFSIZ];
+    static char cwd_str_fmt[BUFSIZ] = "";
     int new_dp_len,
         fmt_len;
     char disp_dir[80];
@@ -307,9 +307,9 @@ int flushit;
 	work_dir = set_work_dir(NULL, min_len);
 
 	if(*s == '/')
-	    strncpy(work_dir, s, sizeof(work_dir));
+	  strncpy(work_dir, s, min_len);
 	else
-	    snprintf(work_dir,  sizeof(work_dir), "%s/%s", homedir, s);
+	  snprintf(work_dir, min_len, "%s/%s", homedir, s);
     }
     /* lop-off trailing "/" for consistency */
     if(strlen(work_dir) > 1 && work_dir[strlen(work_dir) - 1] == '/')
@@ -333,17 +333,14 @@ int flushit;
 	    : _("a directory"),
       down_loading? _("download") : _("upload"));
     wtitle(main_w, TMID, file_title);
-#if 0
-    new_dp_len = strlen(work_dir);
-    if (new_dp_len > 60)  /* we don't want an overflow.. jl 13.4.98 */
-      snprintf(work_dir, sizeof(work_dir), "..%s",work_dir + new_dp_len - 58);
-#endif      
     if((new_dp_len = strlen(work_dir)) > dp_len) {
-	dp_len = new_dp_len;
-	snprintf(cwd_str_fmt, sizeof(cwd_str_fmt), _("Directory: %%-%ds"), dp_len);
+      dp_len = new_dp_len;
+      snprintf(cwd_str_fmt, sizeof(cwd_str_fmt),
+	       _("Directory: %%-%ds"), dp_len);
     }
     if (new_dp_len + (fmt_len = strlen(cwd_str_fmt)) > 75) {
-      snprintf(disp_dir, sizeof(disp_dir), "...%s", work_dir + new_dp_len - 73 + fmt_len);
+      snprintf(disp_dir, sizeof(disp_dir),
+	       "...%s", work_dir + new_dp_len - 73 + fmt_len);
       snprintf(cwd_str, sizeof(cwd_str), cwd_str_fmt, disp_dir);
     }
     else
@@ -427,9 +424,9 @@ int absolut;
 	work_dir = set_work_dir(work_dir, min_len);
 
 	if(*new_dir == '/')
-	    strncpy(work_dir, new_dir, sizeof(work_dir));
+	    strncpy(work_dir, new_dir, min_len);
 	else
-	    snprintf(work_dir, sizeof(work_dir), "%s/%s", homedir, new_dir);
+	    snprintf(work_dir, min_len, "%s/%s", homedir, new_dir);
     }
     new_filedir(dirdat, 1);
 }
@@ -543,7 +540,7 @@ filedir(howmany, downloading)
 int howmany;
 int downloading;
 {
-    time_t click_time;
+    time_t click_time = (time_t) 0;
 
     how_many = howmany;
     down_loading = downloading;
