@@ -17,6 +17,7 @@
  */
 #include "port.h"
 #include "minicom.h"
+#include "intl.h"
 
 #ifndef _SELECT
 
@@ -53,7 +54,8 @@ int dummy;
 {
   signal(ACK, sigack);
   if (waiting) longjmp(ackjmp, 1);
-  printf("sigack: unexpected ACK signal &^%%$!! (pardon my French)\r\n");
+  printf(_("sigack: unexpected ACK signal &^%%$!! (pardon my French)%c\n",
+	   '\r'));
 }
 
 /*
@@ -68,7 +70,7 @@ static void kinstall()
   char prog[128];
 
   if (pipe(pipe1) < 0 || pipe(pipe2) < 0)
-  	leave("minicom: out of file descriptors\n");
+  	leave(_("minicom: out of file descriptors\n"));
   tokeyserv = pipe1[1];
   fromkeyserv = pipe2[0];
 
@@ -80,7 +82,7 @@ static void kinstall()
 
   switch(keypid = fork()) {
   	case -1:
-  		leave("minicom: could not fork.\n");
+  		leave(_("minicom: could not fork.\n"));
   		break;
   	case 0: /* Child */
 
@@ -110,7 +112,7 @@ static void kinstall()
   			buf[0] = KSTOP;
   			write(tokeyserv, buf, 2);
   			if (kill(keypid, HELLO) < 0) {
-  				leave("minicom: could not exec keyserv\n");
+  				leave(_("minicom: could not exec keyserv\n"));
   			}
 			/* Do nothing 'till ACK signal */
 			while(1) pause();
