@@ -11,6 +11,7 @@
  *
  * fmg 1/11/94 color mods
  * jl  22.06.97 log it when DCD drops
+ * jl  02.06.98 added call duration to the "Gone offline" log line
  *
  */
 #include "port.h"
@@ -347,9 +348,14 @@ static void ret_csr()
  */
 void mode_status()
 {
-  wlocate(st, 20, 0);
-  wprintf(st, "%6.6s %s%s1", P_BAUDRATE, P_BITS, P_PARITY);
-  ret_csr();
+  if (st) { /* if swich off status line - NOT print !!! (vlk@st.simbirsk.su) */
+    wlocate(st, 20, 0);
+    if (P_SHOWSPD[0] == 'l')
+      wprintf(st, "%6ld %s%s1", linespd, P_BITS, P_PARITY);
+    else
+      wprintf(st, "%6.6s %s%s1", P_BAUDRATE, P_BITS, P_PARITY);
+    ret_csr();
+  }
 }
 
 /*
@@ -379,16 +385,19 @@ void curs_status()
   ret_csr();
 }
 
+time_t old_online = -1;
+
 /*
  * Update the online time.
  */
 static void updtime()
 {
-  static int old_online = -1;
 
   if (old_online == online) return;
-  if ((old_online >= 0) && (online < 0))
-	do_log(_("Gone offline"));  /* jl 22.06.97 */
+  if ((old_online >= 0) && (online < 0)) {
+    do_log(_("Gone offline (%ld:%02ld:%02ld)"),
+      old_online / 3600, (old_online / 60) % 60, old_online % 60);
+  }
   old_online = online;
   if (st != NIL_WIN) {
   	time_status();
@@ -427,17 +436,23 @@ void timer_update()
 		m_sethwf(portfd, 0);
 	}
 #endif
+	if (online >= 0 && old_online >= 0) {
+	  /* First update the timer for call duration.. */
+	  time(&t1);
+	  online = t1 - start;
+	  updtime();
+	}
+	/* ..and THEN notify that we are now offline */
   	online = -1;
   	updtime();
   }
 
   /* Update online time */
   if (online >= 0) {
-  	time(&t1);
-  	if (t1 > (online + start + 59)) {
-  		online = t1 - start;
-  		updtime();
-  	}
+    time(&t1);
+    online = t1 - start;
+    if (online > (old_online + 59))
+      updtime();
   }
 }
 
