@@ -908,6 +908,7 @@ char **argv;
   capfp = (FILE *)NULL;
   docap = 0;
   online = -1;
+  linespd = 0;
   stdattr = XA_NORMAL;
   us = NIL_WIN;
   addlf = 0;
@@ -1172,6 +1173,7 @@ char **argv;
   buf[0] = 0;
 
   read_parms();
+  num_hist_lines = atoi(P_HISTSIZE);
 
   stdwin = NIL_WIN; /* It better be! */
 
@@ -1199,7 +1201,7 @@ char **argv;
   if (win_init(tfcolor, tbcolor, XA_NORMAL) < 0) leave("");
 
   if (COLS < 40 || LINES < 10) {
-  	leave("Sorry. Your screen is too small.\n");
+  	leave(_("Sorry. Your screen is too small.\n"));
   }
 
   if (dosetup) {
