@@ -23,6 +23,7 @@
  */
 #include "port.h"
 #include "minicom.h"
+#include "intl.h"
  
 #define OK	0
 #define ERR	-1
@@ -87,11 +88,11 @@ int execscript();
  * Print something formatted to stderr.
  */
 /*VARARGS*/ 
-void s_error(fmt, a1, a2, a3)
+void s_error(fmt, a1, a2, a3, a4)
 char *fmt;
-char *a1, *a2, *a3;
+char *a1, *a2, *a3, *a4;
 {
-  fprintf(stderr, fmt, a1, a2, a3);
+  fprintf(stderr, fmt, a1, a2, a3, a4);
 }
 
 /*
@@ -133,8 +134,8 @@ char *env;
 void syntaxerr(s)
 char *s;
 {
-  s_error("script \"%s\": syntax error in line %d %s\r\n", curenv->scriptname,
-  	thisline->lineno, s);
+  s_error(_("script \"%s\": syntax error in line %d %s%s\n"),
+	  curenv->scriptname, thisline->lineno, s, "\r");
   exit(1);	
 }
 
@@ -159,7 +160,8 @@ int dummy;
   alarm(1);
 
   if (--gtimeout == 0) {
-  	s_error("script \"%s\": global timeout\r\n", curenv->scriptname);
+  	s_error(_("script \"%s\": global timeout%s\n"),
+		curenv->scriptname,"\r");
   	exit(1);
   }	
   if (inexpect && etimeout && --etimeout == 0) longjmp(ejmp, 1);
@@ -254,7 +256,7 @@ char **s;
   buf[idx] = 0;	
   (*s) += len;
   skipspace(s);	
-  if (sawesc || sawq) syntaxerr("(badly formed word)");
+  if (sawesc || sawq) syntaxerr(_("(word contains ESC or quote)"));
   return(buf);
 }
 
@@ -307,7 +309,7 @@ char *s;
   int no = 0;
 
   if ((fp = fopen(s, "r")) == (FILE *)0) {
-  	s_error("runscript: couldn't open %s\r\n", s);
+  	s_error(_("runscript: couldn't open %s%s\n"), s, "\r");
   	exit(1);
   }
   
@@ -318,7 +320,7 @@ char *s;
   	if (*t == '\n') continue;
   	if (  ((tl = (struct line *)malloc(sizeof (struct line))) == LNULL) ||
   	      ((tl->line = strsave(t)) == CNULL)) {
-  			s_error("script %s: out of memory\r\n", s);
+  			s_error(_("script %s: out of memory%s\n"), s, "\r");
   			exit(1);
   	}
   	if (prev)
@@ -416,13 +418,14 @@ int cr;
   	if (!strcmp(v->name, name)) return(v);
   }
   if (!cr) {
-  	s_error("script \"%s\" line %d: unknown variable \"%s\"\r\n",
-  		curenv->scriptname, thisline->lineno, name);
+  	s_error(_("script \"%s\" line %d: unknown variable \"%s\"%s\n"),
+  		curenv->scriptname, thisline->lineno, name, "\r");
   	exit(1);
   }
   if ((v = (struct var *)malloc(sizeof(struct var))) == VNULL ||
       (v->name = strsave(name)) == CNULL) {
-  	s_error("script \"%s\": out of memory\r\n", curenv->scriptname);
+  	s_error(_("script \"%s\": out of memory%s\n"),
+		curenv->scriptname, "\r");
   	exit(1);
   }
   if (end)
@@ -459,21 +462,21 @@ struct line **buildexpect()
   
   for(f = 0; f < 16; f++) {
   	if (thisline == LNULL) {
-  		s_error("script \"%s\": unexpected end of file\r\n", 
-  			curenv->scriptname);
+  		s_error(_("script \"%s\": unexpected end of file%s\n"), 
+  			curenv->scriptname, "\r");
   		exit(1);	
   	}
   	t = thisline->line;
   	w = getword(&t);
   	if (!strcmp(w, "}")) {
-  		if (*t) syntaxerr("(garbage after })"); 
+  		if (*t) syntaxerr(_("(garbage after })")); 
 		seq[f] = NULL;
   		return(seq);
   	}
   	seq[f] = thisline;
   	thisline = thisline->next;
   }
-  if (f == 16) syntaxerr("(too many arguments)");
+  if (f == 16) syntaxerr(_("(too many arguments)"));
   return(seq);
 }
 
@@ -492,16 +495,16 @@ char *text;
   char *action = CNULL;
 
   if (inexpect) {
-  	s_error("script \"%s\" line %d: nested expect\r\n", curenv->scriptname,
-  		thisline->lineno);
-  	exit(1);
+    s_error(_("script \"%s\" line %d: nested expect%s\n"),
+	    curenv->scriptname, thisline->lineno, "\r");
+    exit(1);
   }
   etimeout = 120;
   inexpect = 1;
 
   s = getword(&text);
   if (!strcmp(s, "{")) {
-  	if (*text) syntaxerr("(garbage after {)");
+  	if (*text) syntaxerr(_("(garbage after {)"));
   	thisline = thisline->next;
   	seq = buildexpect();
   } else {
@@ -520,9 +523,9 @@ char *text;
   		seq[f] = LNULL;
   		skipspace(&s);
   		w = getword(&s);
-  		if (w == CNULL) syntaxerr("(argument expected)");
+  		if (w == CNULL) syntaxerr(_("(argument expected)"));
   		val = getnum(w);
-  		if (val == 0) syntaxerr("(invalid argument)");
+  		if (val == 0) syntaxerr(_("(invalid argument)"));
   		etimeout = val;
   		skipspace(&s);
   		if (*s != 0) toact = s;
@@ -617,13 +620,13 @@ char *text;
   int len;
 
   w = getword(&text);
-  if (w == CNULL || *text) syntaxerr("(in goto/gosub label)");
+  if (w == CNULL || *text) syntaxerr(_("(in goto/gosub label)"));
   snprintf(buf, sizeof(buf), "%s:", w);
   len = strlen(buf);
   for(l = curenv->lines; l; l = l->next) if (!strncmp(l->line, buf, len)) break;
   if (l == LNULL) {
-  	s_error("script \"%s\" line %d: label \"%s\" not found\r\n",
-  		curenv->scriptname, thisline->lineno, w);
+  	s_error(_("script \"%s\" line %d: label \"%s\" not found%s\n"),
+  		curenv->scriptname, thisline->lineno, w, "\r");
   	exit(1);
   }
   thisline = l;
@@ -645,8 +648,8 @@ char *text;
   
   while(ret != ERR) {
 	if ((thisline = thisline->next) == LNULL) {
-		s_error("script \"%s\": no return from gosub\r\n", 
-					curenv->scriptname);
+		s_error(_("script \"%s\": no return from gosub%s\n"), 
+			curenv->scriptname, "\r");
 		exit(1);
 	}
 	ret = s_exec(thisline->line);
@@ -691,7 +694,7 @@ char *text;
   struct var *v;
 
   w = getword(&text);
-  if (w == CNULL) syntaxerr("(missing var name)");
+  if (w == CNULL) syntaxerr(_("(missing var name)"));
   v = getvar(w, 1);
   if (*text) v->value = getnum(getword(&text));
   return(OK);
@@ -707,7 +710,7 @@ char *text;
   struct var *v;
   
   w = getword(&text);
-  if (w == CNULL)  syntaxerr("(expected variable)");
+  if (w == CNULL)  syntaxerr(_("(expected variable)"));
   v = getvar(w, 0);
   v->value--;
   return(OK);
@@ -723,7 +726,7 @@ char *text;
   struct var *v;
   
   w = getword(&text);
-  if (w == CNULL)  syntaxerr("(expected variable)");
+  if (w == CNULL)  syntaxerr(_("(expected variable)"));
   v = getvar(w, 0);
   v->value++;
   return(OK);
@@ -751,7 +754,7 @@ char *text;
   }
   if ((w = getword(&text)) == CNULL) syntaxerr("(if)");
   n2 = getnum(w);
-  if (!*text) syntaxerr("(expected command after if)");
+  if (!*text) syntaxerr(_("(expected command after if)"));
   
   if (op == '=') {
   	if (n1 != n2) return(OK);
@@ -762,7 +765,7 @@ char *text;
   } else if (op == '<') {
   	if (n1 >= n2) return(OK);
   } else {
-  	syntaxerr("(unknown operator)");
+  	syntaxerr(_("(unknown operator)"));
   }
   return(s_exec(text));
 }
@@ -777,8 +780,8 @@ char *text;
   int val;
 
   w = getword(&text);
-  if(w == CNULL) syntaxerr("(argument expected)");
-  if ((val = getnum(w)) == 0) syntaxerr("(invalid argument)");
+  if(w == CNULL) syntaxerr(_("(argument expected)"));
+  if ((val = getnum(w)) == 0) syntaxerr(_("(invalid argument)"));
   gtimeout = val;
   return(OK);
 }
@@ -800,7 +803,7 @@ char *text;
 		return(OK);
 	}
   }	
-  syntaxerr("(unexpected argument)");
+  syntaxerr(_("(unexpected argument)"));
   return(ERR);
 }
 
@@ -827,8 +830,8 @@ char *text;
 int dobreak()
 {
   if (!inexpect) {
-  	s_error("script \"%s\" line %d: break outside of expect\r\n",
-  		curenv->scriptname, thisline->lineno);
+  	s_error(_("script \"%s\" line %d: break outside of expect%s\n"),
+  		curenv->scriptname, thisline->lineno, "\r");
   	exit(1);
   }
   return(BREAK);
@@ -844,11 +847,11 @@ char *text;
   struct env *oldenv;
   int er;
 
-  if (*text == 0) syntaxerr("(argument expected)");
+  if (*text == 0) syntaxerr(_("(argument expected)"));
 
   if (inexpect) {
-  	s_error("script \"%s\" line %d: call inside expect\r\n",
-  			curenv->scriptname);
+  	s_error(_("script \"%s\" line %d: call inside expect%s\n"),
+  			curenv->scriptname, "\r");
   	exit(1);
   }
 
@@ -908,8 +911,8 @@ char *text;
 
   /* Command not found? */
   if (k->command == (char *)NULL) {
-	s_error("script \"%s\" line %d: unknown command \"%s\"\r\n",
-  		curenv->scriptname, thisline->lineno, w);
+	s_error(_("script \"%s\" line %d: unknown command \"%s\"%s\n"),
+  		curenv->scriptname, thisline->lineno, w, "\r");
 	exit(1);
   }
   return((*(k->fn))(text));
@@ -955,11 +958,17 @@ char **argv;
 #if 0 /* Shouldn't need this.. */
   signal(SIGHUP, SIG_IGN);
 #endif
+
+#ifdef _I18N_
+  bindtextdomain("minicom", "/usr/share/locale");
+  textdomain("minicom");
+#endif
+
   init_env();
   memset(inbuf, 0, sizeof(inbuf));
 
   if (argc < 2) {
-  	s_error("Usage: runscript <scriptfile> [homedir]\r\n");
+  	s_error(_("Usage: runscript <scriptfile> [homedir]%s\n"),"\r");
   	return(1);
   }
 
