@@ -506,7 +506,7 @@ int swf;
   if (par[0] == 'E')
 	tty.c_cflag |= PARENB;
   else if (par[0] == 'O')
-	tty.c_cflag |= PARODD;
+	tty.c_cflag |= (PARENB | PARODD);
 
   tcsetattr(fd, TCSANOW, &tty);
 
