@@ -333,6 +333,7 @@ int nr;
   (void) setcbreak(2); /* Raw, no echo. */
   if (win) close(pipefd[0]);
   (void) mcd("");
+  timer_update();
 
   /* If we got interrupted, status != 0 */
   if (win && (status & 0xFF00) == 0) {
@@ -570,7 +571,8 @@ char *s, *l, *p;
 
   if (mcd(P_SCRIPTDIR) < 0) return;
 
-  snprintf(cmdline, sizeof(cmdline), "%s %s", P_SCRIPTPROG, scr_name);
+  snprintf(cmdline, sizeof(cmdline), "%s %s %s",
+	   P_SCRIPTPROG, scr_name, homedir);
 
   switch(udpid = fork()) {
   	case -1:
