@@ -16,11 +16,13 @@
  *		2 of the License, or (at your option) any later version.
  *
  * // jl 04.09.97 character map conversions in and out
+ *    jl 06.07.98 use conversion tables with the capture file
  */
 #include "port.h"
 #include "window.h"
 #include "vt100.h"
 #include "config.h"
+#include "configsym.h"
 #include "patchlevel.h"
 
 #define OLD 0
@@ -102,8 +104,8 @@ static struct escseq vt_keys[] = {
 };
 
 /* Two tables for user-defined character map conversions.
- * defmap.h should contain all characters 0-255 in order to default to
- * no conversion.    jl 04.09.1997
+ * defmap.h should contain all characters 0-255 in ascending order
+ * to default to no conversion.    jl 04.09.1997
  */
 
 unsigned char vt_inmap[256] = {
@@ -162,6 +164,7 @@ static int vt_fg;		/* Standard foreground color. */
 static int vt_bg;		/* Standard background color. */
 static int vt_keypad;		/* Keypad mode. */
 static int vt_cursor;		/* cursor key mode. */
+static int vt_asis = 0;		/* 8bit clean mode. */
 static int vt_bs = 8;		/* Code that backspace key sends. */
 static int vt_insert = 0;	/* Insert mode */
 static int vt_crlf = 0;		/* Return sends CR/LF */
@@ -273,7 +276,7 @@ int add;
 }
 
 /* Change some things on the fly. */
-void vt_set(addlf, wrap, capfp, docap, bscode, echo, cursor)
+void vt_set(addlf, wrap, capfp, docap, bscode, echo, cursor, asis)
 int addlf;
 int wrap;
 FILE *capfp;
@@ -281,6 +284,7 @@ int docap;
 int bscode;
 int echo;
 int cursor;
+int asis;
 {
   if (addlf >= 0) vt_addlf = addlf;
   if (wrap >= 0)  vt_win->wrap = vt_wrap = wrap;
@@ -291,6 +295,7 @@ int cursor;
   if (echo >= 0) vt_echo = echo;
 #endif
   if (cursor >= 0) vt_cursor = cursor;
+  if (asis >=0) vt_asis = asis;
 }
 
 /* Output a string to the modem. */
@@ -1005,9 +1010,11 @@ int ch;
   /* Now see which state we are in. */
   switch(esc_s) {
 	case 0: /* Normal character */
+		if (vt_docap == 1)
+			fputc(P_CONVCAP[0]=='Y'? vt_inmap[c]: c, vt_capfp);
 	        c = vt_inmap[c];    /* conversion 04.09.97 / jl */
 #if TRANSLATE
-		if (vt_type == VT100) {
+		if (vt_type == VT100 && vt_asis == 0) {
 			if (vt_insert)
 				winschar2(vt_win, vt_trans[vt_charset][c], 1);
 			else
@@ -1021,8 +1028,6 @@ int ch;
 #if TRANSLATE
 		}
 #endif
-		if (vt_docap == 1)
-			fputc(c, vt_capfp);
 		break;
 	case 1: /* ESC seen */
 		state1(c);
